pygeodesy.deprecated.classes._Deprecated_NamedTuple

Package pygeodesy :: Package deprecated :: Module classes :: Class _Deprecated_NamedTuple |
[frames] | no frames]

# Class _Deprecated_NamedTuple

       object --+
                |
            tuple --+
                    |
       object --+   |
                |   |
     named._Named --+
                    |
    named._NamedTuple --+
                        |
                       _Deprecated_NamedTuple

Known Subclasses:
  - ClipCS3Tuple
  - , EasNorExact4Tuple
  - , Transform7Tuple
  - , LatLonExact4Tuple
  - , NearestOn4Tuple
  - , Ned3Tuple
  - , Rhumb7Tuple
  - , RhumbOrder2Tuple
  - , TriAngle4Tuple
  - , UtmUps4Tuple

DEPRECATED, `_NamedTuple` base.

Instance Methods
Inherited from `named._NamedTuple`: `__delattr__`, `__getattr__`, `__hash__`, `__repr__`, `__setattr__`, `__str__`, `dup`, `items`, `iteritems`, `iterunits`, `reUnit`, `toRepr`, `toStr`, `toUnits`, `units` Inherited from `tuple`: `__add__`, `__contains__`, `__eq__`, `__ge__`, `__getattribute__`, `__getitem__`, `__getnewargs__`, `__getslice__`, `__gt__`, `__iter__`, `__le__`, `__len__`, `__lt__`, `__mul__`, `__ne__`, `__rmul__`, `count`, `index` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__init__`, `__reduce__`, `__reduce_ex__`, `__sizeof__`, `__subclasshook__`

Static Methods
a new object with type S, a subtype of T |
__new__(cls, *args, **kwds) New _NamedTuple initialized with `positional` arguments. |

Properties
Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### __new__ (cls, *args, **kwds) Static Method |
New _NamedTuple initialized with `positional` arguments. Arguments: `arg` - Tuple items (`tuple`, `list`, ...) or first tuple item of several more in other positional arguments. `args` - Tuple items (`any`), all positional arguments. `iteration_name` - Only keyword arguments `iteration=None` and `name=NN` are used, any other are silently ignored. Returns: a new object with type S, a subtype of T Raises: `LenError` - Unequal number of positional arguments and number of item `_Names_` or `_Units_`. `TypeError` - The `_Names_` or `_Units_` attribute is not a `tuple` of at least 2 items. `ValueError` - Item name is not a `str` or valid `identifier` or starts with `underscore`. Overrides: object.__new__ (inherited documentation)